=============================================
JSON-any: JSON and unJSON objects of any type
=============================================



Installation
============

This project is published on the `Python Package Index (PyPI) <https://pypi.org>`_ at: `https://pypi.org/project/json-any <https://pypi.org/project/json-any>`_. It should be installable from Python distribution platforms or Integrated Development Environments (IDEs). Otherwise, it can be installed from a command-line console:

- For all users, after acquiring administrative rights:
    - First installation: ``pip install json-any``
    - Installation update: ``pip install --upgrade json-any``
- For the current user (no administrative rights required):
    - First installation: ``pip install --user json-any``
    - Installation update: ``pip install --user --upgrade json-any``



Documentation
=============

The documentation is proposed in the form of a `Wiki site <https://src.koda.cnrs.fr/eric.debreuve/json-any/-/wikis/home>`_.



Acknowledgments
===============

The project is developed with `PyCharm Community <https://www.jetbrains.com/pycharm>`_.

The development relies on several open-source packages (see ``install_requires`` in ``setup.py``).

The code is formatted by `Black <https://github.com/psf/black>`_, *The Uncompromising Code Formatter*.

The imports are ordered by `isort <https://github.com/timothycrosley/isort>`_... *your imports, so you don't have to*.
